@@ -104,8 +104,8 @@ class ActiveResource(object):
         else:
             method = 'POST'
         
-        dict([(k, getattr(self, k)) for k in self.Meta.changed])
-        status, xml = self.__class__._make_request(obj=self, method=method)
+        params = dict([(k, getattr(self, k)) for k in self.Meta.changed])
+        status, xml = self.__class__._make_request(obj=self, method=method, params=params)
         
         if not str(status[0]).startswith('2'):
             return False
